#include <stdlib.h>
#include <stdio.h>

#include <gtk--.h>



class PipesTest : public Gtk_Window {
    Gtk_Label l;
    Gtk_Button b;
    Gtk_VBox *vb;
    Gtk_Text *text;
public:
  PipesTest() 
    : l("Hello World!"),
      b("Hello-button"),
      vb(new Gtk_VBox),
      text(new Gtk_Text)
    {
	add(vb);
	vb->pack_start(l);
	vb->pack_start(b);
	vb->pack_start(*text);
	vb->show();
	l.show();
	b.show();
	text->show();
    }
    
    gint delete_event_impl(GdkEventAny*) { 
	Gtk_Main::instance()->quit(); return 0; 
    }

};


int main(int argc, char *argv[]) {
  Gtk_Main m(&argc,&argv);
  PipesTest *t=new PipesTest;
  t->show();
  m.run();
  printf("After run!\n");
  return(EXIT_SUCCESS);
}












